<?php
//http://www.lastcraft.com/unit_test_documentation.php

class TestOfSimpleParser extends UnitTestCase {

    function setUp() {
        //Make sure errors are not output
	global $g_output_data, $g_err_cnt;
        $g_err_cnt = 0;
        $g_output_data = array();
	
	$this->html = file_get_contents('test.html');
	$foo = '<html><!-- InstanceBegin template="/Templates/travel.dwt" codeOutsideHTMLIsLocked="false" -->
<head>
<!-- InstanceBeginEditable name="doctitle" -->
<script type="text/javascript"> 
//<!-- BEGIN LON-CAPA Internal
var checkwin;

function spellcheckerwindow() {
}
// END LON-CAPA Internal -->
</script>
<script type="text/javascript">
// BEGIN LON-CAPA Internal
// <![CDATA[
    function set_bookmark() {
       bmquery.document.write(
       "<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html><head><meta http-equiv="Content-Type" content="text/html; charset=utf-8" /><title> LON-CAPA Bookmarks<\/title><link rel="stylesheet" type="text/css" href="/adm/css/rairighd%3amsu%3a%3acoordinator%3amsu%3a%23BBBBBB.css" /><\/head><body  link="#003333"  alink="#CC0000"  vlink="#006633"  bgcolor="#BBBBBB"  text="#000044"  style="margin-top: 0px" >"
       +"<center><form method=post"
       +" name=newlink action=/adm/bookmarks target=bmquery "
       +">\n <table width=340 height=150 "
       +"bgcolor=ffffff align=center><tr><td>Link Name:<br /><input "
       +"value=Save /> <input type=button value=lose (no save) "
       +"onclick=javascript:window.close(); /><\/center><\/td>"
       +"<\/tr><\/table><\/form><\/center>"
       +" <\/body> <\/html>" );
       bmquery.document.close();
    }
// ]]>
</script>
<title>Lake Tours</title>
<!-- InstanceEndEditable -->
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<!-- InstanceBeginEditable name="head" -->
<!-- InstanceEndEditable -->
<link href= "travel.css" rel ="stylesheet" type = "text/css" title="Travel Style Sheet">
</head>
<body>
<div id="banner_div"><!-- InstanceBeginEditable name="Masthead Editable Region" -->Lake
  Tours <!-- InstanceEndEditable --></div>
<div id="maincontent_div"><!-- InstanceBeginEditable name="Primary Editable Region" -->
  <p class="foo">Up To: <a href="cruise.htm">Cruise Tours</a> and <a href="travel.htm">Travel</a></p>
  <p>The<strong> Circle Tour cruise of the Inland Lakes</strong> is a relaxed
    4 day excursion. Each day, the cruise visits a different lake. The ship\'s
    captain is well familiar with all of the local flora and fauna and can point
    out the more <em>exotic</em> ovine species which live in abundance along the
    lakeshore. Fine dining is available on the cruise including broiled carp and
    <a href="http://www.bbc.co.uk/food/recipes/database/orangeandwatercresss_67601.shtml" onclick="document.getElementById(\'someId\')">watercress
    salad</a>.</p>
    <!--p><a href="">Instance of commented out Code</a></p-->
  <!-- InstanceEndEditable -->
  <p>Site design by <a href="http://www.msu.edu/%7Ewagnerpe/my_msuwebpages/mymsu.htm">Peter
    Wagner</a>. Copyright 2006, CCC Web Design</p>
</div>
<DIV ID="navigationtool_div">
  <ul>
    <li><a href="travel.htm">Travel Main</a></li>
    <li> <a href="auto.htm">Auto Tours </a></li>
    <li><a href="trolley.htm">Trolley Tours</a> </li>
    <li><a href="cruise.htm">Cruise Tours</a></li>
    <li><a href="manager.htm">Site Manager</a></li>
  </ul>
</div>
</body>
<!-- InstanceEnd --></html>';
	$this->parser = new SimpleParser($this->html);
    }
    
    function testParsing() {
        global $g_output_data, $g_err_cnt, $report_indent;

        $this->assertEqual(sizeOf($g_output_data), 0);
        $this->assertEqual($g_err_cnt, 0);
	
	//Is an object
	$this->assertIsA($this->parser,'SimpleParser');
	//No errors on object creation
	$this->assertIsA($this->parser->Errors, 'array');
	$this->assertEqual(sizeOf($this->parser->Errors), 0);
        $this->assertNoErrors();
    }
    
    function testTags() {
	$tags = array('html','head','script','script','title','meta','link','body','div','div',
			'p','a','a','p','strong','em','a','p','a','div','ul','li','a','li','a',
			'li','a','li','a','li','a');
		//TODO: Split html instead

	$i=0; $lastLine = 0;
	while ($this->parser->nextNode()) {
	    if ($this->parser->NodeType == NODE_TYPE_ELEMENT) {
		$this->assertEqual($this->parser->NodeName, $tags[$i]);
		$i++;
	    } else if ($this->parser->NodeType == NODE_TYPE_ENDELEMENT) {
		//Nothing really to test here
	    } else if ($this->parser->NodeType == NODE_TYPE_COMMENT) {
		$this->assertEqual($this->parser->NodeName, "Comment");
	    } else {
		$this->assertEqual($this->parser->NodeType, NODE_TYPE_TEXT);
		$this->assertNotEqual($this->parser->CData, "");
	    }
	    $this->assertNotEqual($this->parser->LineNumber, 0);
	    $this->assertTrue($this->parser->LineNumber >= $lastLine);
	    $lastLine = $this->parser->LineNumber;
	}
	$this->assertEqual($this->parser->NodeType, NODE_TYPE_DONE);
	$this->assertEqual($i, sizeOf($tags));

	$this->assertIsA($this->parser->Errors, 'array');
	$this->assertEqual(sizeOf($this->parser->Errors), 0);
        $this->assertNoErrors();
    }
    
    function testComments() {
	$comments = 0;
	$cdatas = 0;
	while ($this->parser->nextNode()) {
	    if ($this->parser->NodeType == NODE_TYPE_COMMENT) {
		$this->assertEqual($this->parser->NodeName, "Comment");
		$this->assertWantedPattern("/Instance|LON-CAPA/", $this->parser->CData);
		$this->assertEqual(sizeOf($this->parser->NodeAttributes), 0);
		$comments++;
	    } else if ($this->parser->NodeType == NODE_TYPE_TEXT && 
			$this->parser->NodeName == 'CDATA') {
		$this->assertWantedPattern("/function set_bookmark/", $this->parser->CData);
		$this->assertEqual(sizeOf($this->parser->NodeAttributes), 0);
		$cdatas++;
	    }
	}
	$this->assertEqual($comments, 12);
	$this->assertEqual($cdatas, 1);
    }
    
    function testAttributes() {
	while ($this->parser->nextNode()) {
	    if ($this->parser->NodeType == NODE_TYPE_ELEMENT) {
		$this->assertIsA($this->parser->NodeAttributes, 'array');
		
		if ($this->parser->NodeName == "link") {
		    //Attributes with spaces
		    $this->assertEqual(sizeOf($this->parser->NodeAttributes), 4);
		    $this->assertEqual($this->parser->NodeAttributes['href'], "travel.css");
		    $this->assertEqual($this->parser->NodeAttributes['rel'], "stylesheet");
		    $this->assertEqual($this->parser->NodeAttributes['type'], "text/css");
		    $this->assertEqual($this->parser->NodeAttributes['title'], "Travel Style Sheet");

		} else if ($this->parser->NodeName == "div") {
		    //Capatilized attributes
		    $this->assertEqual(sizeOf($this->parser->NodeAttributes), 1);
		    $this->assertNotNull($this->parser->NodeAttributes['id']);
		}
		
	    } else if ($this->parser->NodeType == NODE_TYPE_ENDELEMENT) {
		//End elements don't have attributes
		$this->assertIsA($this->parser->NodeAttributes, 'array');
		$this->assertEqual(sizeOf($this->parser->NodeAttributes), 0);
	    }
	}
    }
}
?>
